@@ -3,7 +3,7 @@ import sys
 import inspect
 import logging
 
-from flask import Flask, g, request
+from flask import Flask, g, request, json
 from datetime import timedelta
 from logging.handlers import WatchedFileHandler
 from cachelib import MemcachedCache, SimpleCache
@@ -20,7 +20,9 @@ ENVIRONMENT_TYPES = ("development", "testing", "production")
 DEFAULT_ENVIRONMENT_TYPE = "development"
 DEFAULT_SESSION_EXPIRATION_TIME = 86400 * 7 * 2
 DEFAULT_TOKEN_TTL = 86400 * 7 * 2
-DEFAULT_LOG_FORMAT = "[%(asctime)s] %(levelname)s %(filename)s:%(lineno)d %(request_id)s %(message)s"
+DEFAULT_LOG_FORMAT = (
+    "[%(asctime)s] %(levelname)s %(filename)s:%(lineno)d %(request_id)s %(message)s"
+)
 DEFAULT_LOG_LEVEL = "debug"
 DEFAULT_FILECACHE_DIR = "/var/cache/uengine"
 
@@ -28,10 +30,10 @@ DEFAULT_FILECACHE_DIR = "/var/cache/uengine"
 class RequestIDFilter(logging.Filter):
     def filter(self, record):
         if request:
-            if 'X-Request-ID' in request.headers:
-                record.request_id = request.headers.get('X-Request-ID')
-            elif 'request_id' in request.args:
-                record.request_id = request.args.get('request_id')
+            if "X-Request-ID" in request.headers:
+                record.request_id = request.headers.get("X-Request-ID")
+            elif "request_id" in request.args:
+                record.request_id = request.args.get("request_id")
             else:
                 record.request_id = getattr(g, "request_id", None)
         else:
@@ -41,7 +43,6 @@ class RequestIDFilter(logging.Filter):
 
 
 class Base:
-
     def __init__(self):
         class_file = inspect.getfile(self.__class__)
         self.app_dir = os.path.dirname(os.path.abspath(class_file))
@@ -102,6 +103,7 @@ class Base:
             return MemcachedCache(ctx.cfg.get("memcache_backends"))
 
         from .cache import patch_delete_many
+
         SimpleCache.delete_many = patch_delete_many
         return SimpleCache()
 
@@ -109,6 +111,7 @@ class Base:
     def __setup_request_cache():
         ctx.log.debug("Setting up a request local cache")
         from .cache import RequestLocalCache
+
         return RequestLocalCache()
 
     @staticmethod
@@ -178,7 +181,7 @@ class Base:
                 flask.config[k] = v
         flask.secret_key = ctx.cfg.get("app_secret_key")
         ctx.log.debug("Setting up JSON encoder")
-        flask.json_encoder = MongoJSONEncoder
+        json.JSONEncoder = MongoJSONEncoder
 
         # pylint: disable=unused-variable
         @flask.before_request
@@ -190,10 +193,13 @@ class Base:
 
             try:
                 from . import profilers
+
                 flask.before_request(profilers.before_request)
                 flask.after_request(profilers.after_request)
             except ImportError:
-                ctx.log.exception("error importing profiler, profiling will be disabled")
+                ctx.log.exception(
+                    "error importing profiler, profiling will be disabled"
+                )
 
             # pylint: disable=unused-variable
             @flask.before_request
@@ -202,32 +208,43 @@ class Base:
 
             @flask.before_request
             def log_all_requests():
-                msg = "REQ_%s %s data=%s" % (
-                    request.method, request.path, request.json)
+                msg = "REQ_%s %s data=%s" % (request.method, request.path, request.json)
                 ctx.log.debug(msg)
 
             @flask.after_request
             def log_all_responses(response):
-                if response.content_type == 'application/json':
-                    ctx.log.debug(" ".join(map(str, [
-                        response.status,
-                        str(response.headers).rstrip('\r\n'),
-                        response.get_data(),
-                    ])))
+                if response.content_type == "application/json":
+                    ctx.log.debug(
+                        " ".join(
+                            map(
+                                str,
+                                [
+                                    response.status,
+                                    str(response.headers).rstrip("\r\n"),
+                                    response.get_data(),
+                                ],
+                            )
+                        )
+                    )
                 else:
                     ctx.log.debug(
-                        " ".join(map(str, [response.status, str(response.headers).rstrip('\r\n')])))
+                        " ".join(
+                            map(
+                                str,
+                                [response.status, str(response.headers).rstrip("\r\n")],
+                            )
+                        )
+                    )
                 return response
 
         return flask
 
     def __read_config(self):
-        config_filename = os.path.join(
-            self.base_dir, "config", "%s.py" % ctx.envtype)
+        config_filename = os.path.join(self.base_dir, "config", "%s.py" % ctx.envtype)
         with open(config_filename) as f:
             config = {}
             text = f.read()
-            code = compile(text, config_filename, 'exec')
+            code = compile(text, config_filename, "exec")
             exec(code, config)  # pylint: disable=exec-used
             del config["__builtins__"]
             return config
@@ -236,13 +253,13 @@ class Base:
         ctx.log.debug("Setting up sessions")
 
         e_time = ctx.cfg.get("session_ttl", DEFAULT_SESSION_EXPIRATION_TIME)
-        self.flask.session_interface = MongoSessionInterface(
-            collection_name='sessions')
+        self.flask.session_interface = MongoSessionInterface(collection_name="sessions")
         self.flask.permanent_session_lifetime = timedelta(seconds=e_time)
         self.session_expiration_time = timedelta(seconds=e_time)
         self.session_auto_cleanup = ctx.cfg.get("session_auto_cleanup", True)
         self.session_auto_cleanup_trigger = ctx.cfg.get(
-            "session_auto_cleanup_rand_trigger", 0.05)
+            "session_auto_cleanup_rand_trigger", 0.05
+        )
 
     def __setup_error_handling(self):
         self.flask.register_error_handler(ApiError, handle_api_error)
